@@ -4,6 +4,7 @@ import pytest
 from dirty_equals import IsOneOf
 from fastapi import FastAPI, Query
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 from pydantic import BaseModel, Field
 
 app = FastAPI()
@@ -31,18 +32,20 @@ def read_model_required_list_str(p: Annotated[QueryModelRequiredListStr, Query()
     ["/required-list-str", "/model-required-list-str"],
 )
 def test_required_list_str_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {
-                "title": "P",
-                "type": "array",
-                "items": {"type": "string"},
-            },
-            "name": "p",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {
+                    "title": "P",
+                    "type": "array",
+                    "items": {"type": "string"},
+                },
+                "name": "p",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -101,18 +104,20 @@ async def read_model_required_list_alias(
     ["/required-list-alias", "/model-required-list-alias"],
 )
 def test_required_list_str_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {
-                "title": "P Alias",
-                "type": "array",
-                "items": {"type": "string"},
-            },
-            "name": "p_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {
+                    "title": "P Alias",
+                    "type": "array",
+                    "items": {"type": "string"},
+                },
+                "name": "p_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -199,18 +204,20 @@ async def read_model_required_list_validation_alias(
     ["/required-list-validation-alias", "/model-required-list-validation-alias"],
 )
 def test_required_list_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {
-                "title": "P Val Alias",
-                "type": "array",
-                "items": {"type": "string"},
-            },
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {
+                    "title": "P Val Alias",
+                    "type": "array",
+                    "items": {"type": "string"},
+                },
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -305,18 +312,20 @@ def read_model_required_list_alias_and_validation_alias(
     ],
 )
 def test_required_list_alias_and_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {
-                "title": "P Val Alias",
-                "type": "array",
-                "items": {"type": "string"},
-            },
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {
+                    "title": "P Val Alias",
+                    "type": "array",
+                    "items": {"type": "string"},
+                },
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
