@@ -3,6 +3,7 @@ from typing import Annotated, Optional
 import pytest
 from fastapi import FastAPI, Query
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 from pydantic import BaseModel, Field
 
 app = FastAPI()
@@ -34,20 +35,22 @@ async def read_model_optional_list_str(
     ["/optional-list-str", "/model-optional-list-str"],
 )
 def test_optional_list_str_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [
-                    {"items": {"type": "string"}, "type": "array"},
-                    {"type": "null"},
-                ],
-                "title": "P",
-            },
-            "name": "p",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [
+                        {"items": {"type": "string"}, "type": "array"},
+                        {"type": "null"},
+                    ],
+                    "title": "P",
+                },
+                "name": "p",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -99,20 +102,22 @@ async def read_model_optional_list_alias(
     ["/optional-list-alias", "/model-optional-list-alias"],
 )
 def test_optional_list_str_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [
-                    {"items": {"type": "string"}, "type": "array"},
-                    {"type": "null"},
-                ],
-                "title": "P Alias",
-            },
-            "name": "p_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [
+                        {"items": {"type": "string"}, "type": "array"},
+                        {"type": "null"},
+                    ],
+                    "title": "P Alias",
+                },
+                "name": "p_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -178,20 +183,22 @@ def read_model_optional_list_validation_alias(
     ["/optional-list-validation-alias", "/model-optional-list-validation-alias"],
 )
 def test_optional_list_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [
-                    {"items": {"type": "string"}, "type": "array"},
-                    {"type": "null"},
-                ],
-                "title": "P Val Alias",
-            },
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [
+                        {"items": {"type": "string"}, "type": "array"},
+                        {"type": "null"},
+                    ],
+                    "title": "P Val Alias",
+                },
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -264,20 +271,22 @@ def read_model_optional_list_alias_and_validation_alias(
     ],
 )
 def test_optional_list_alias_and_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [
-                    {"items": {"type": "string"}, "type": "array"},
-                    {"type": "null"},
-                ],
-                "title": "P Val Alias",
-            },
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [
+                        {"items": {"type": "string"}, "type": "array"},
+                        {"type": "null"},
+                    ],
+                    "title": "P Val Alias",
+                },
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
