@@ -2,6 +2,7 @@ import importlib
 
 import pytest
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 from ...utils import needs_py310
 
@@ -197,167 +198,169 @@ def test_post_id_foo(client: TestClient):
 def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "info": {
-            "title": "FastAPI",
-            "version": "0.1.0",
-        },
-        "openapi": "3.1.0",
-        "paths": {
-            "/items/{item_id}": {
-                "put": {
-                    "operationId": "update_item_items__item_id__put",
-                    "parameters": [
-                        {
-                            "in": "path",
-                            "name": "item_id",
-                            "required": True,
-                            "schema": {
-                                "title": "Item Id",
-                                "type": "integer",
-                            },
-                        },
-                    ],
-                    "requestBody": {
-                        "content": {
-                            "application/json": {
+    assert response.json() == snapshot(
+        {
+            "info": {
+                "title": "FastAPI",
+                "version": "0.1.0",
+            },
+            "openapi": "3.1.0",
+            "paths": {
+                "/items/{item_id}": {
+                    "put": {
+                        "operationId": "update_item_items__item_id__put",
+                        "parameters": [
+                            {
+                                "in": "path",
+                                "name": "item_id",
+                                "required": True,
                                 "schema": {
-                                    "$ref": "#/components/schemas/Body_update_item_items__item_id__put",
+                                    "title": "Item Id",
+                                    "type": "integer",
                                 },
                             },
-                        },
-                        "required": True,
-                    },
-                    "responses": {
-                        "200": {
-                            "content": {
-                                "application/json": {
-                                    "schema": {},
-                                },
-                            },
-                            "description": "Successful Response",
-                        },
-                        "422": {
+                        ],
+                        "requestBody": {
                             "content": {
                                 "application/json": {
                                     "schema": {
-                                        "$ref": "#/components/schemas/HTTPValidationError",
+                                        "$ref": "#/components/schemas/Body_update_item_items__item_id__put",
                                     },
                                 },
                             },
-                            "description": "Validation Error",
+                            "required": True,
                         },
+                        "responses": {
+                            "200": {
+                                "content": {
+                                    "application/json": {
+                                        "schema": {},
+                                    },
+                                },
+                                "description": "Successful Response",
+                            },
+                            "422": {
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/HTTPValidationError",
+                                        },
+                                    },
+                                },
+                                "description": "Validation Error",
+                            },
+                        },
+                        "summary": "Update Item",
                     },
-                    "summary": "Update Item",
                 },
             },
-        },
-        "components": {
-            "schemas": {
-                "Body_update_item_items__item_id__put": {
-                    "properties": {
-                        "item": {
-                            "$ref": "#/components/schemas/Item",
-                        },
-                        "user": {
-                            "$ref": "#/components/schemas/User",
-                        },
-                    },
-                    "required": [
-                        "item",
-                        "user",
-                    ],
-                    "title": "Body_update_item_items__item_id__put",
-                    "type": "object",
-                },
-                "HTTPValidationError": {
-                    "properties": {
-                        "detail": {
-                            "items": {
-                                "$ref": "#/components/schemas/ValidationError",
+            "components": {
+                "schemas": {
+                    "Body_update_item_items__item_id__put": {
+                        "properties": {
+                            "item": {
+                                "$ref": "#/components/schemas/Item",
                             },
-                            "title": "Detail",
-                            "type": "array",
-                        },
-                    },
-                    "title": "HTTPValidationError",
-                    "type": "object",
-                },
-                "Item": {
-                    "properties": {
-                        "name": {
-                            "title": "Name",
-                            "type": "string",
-                        },
-                        "description": {
-                            "title": "Description",
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                        },
-                        "price": {"title": "Price", "type": "number"},
-                        "tax": {
-                            "title": "Tax",
-                            "anyOf": [{"type": "number"}, {"type": "null"}],
-                        },
-                    },
-                    "required": [
-                        "name",
-                        "price",
-                    ],
-                    "title": "Item",
-                    "type": "object",
-                },
-                "User": {
-                    "properties": {
-                        "username": {
-                            "title": "Username",
-                            "type": "string",
-                        },
-                        "full_name": {
-                            "title": "Full Name",
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                        },
-                    },
-                    "required": [
-                        "username",
-                    ],
-                    "title": "User",
-                    "type": "object",
-                },
-                "ValidationError": {
-                    "properties": {
-                        "ctx": {"title": "Context", "type": "object"},
-                        "input": {"title": "Input"},
-                        "loc": {
-                            "items": {
-                                "anyOf": [
-                                    {
-                                        "type": "string",
-                                    },
-                                    {
-                                        "type": "integer",
-                                    },
-                                ],
+                            "user": {
+                                "$ref": "#/components/schemas/User",
                             },
-                            "title": "Location",
-                            "type": "array",
-                        },
-                        "msg": {
-                            "title": "Message",
-                            "type": "string",
-                        },
-                        "type": {
-                            "title": "Error Type",
-                            "type": "string",
                         },
+                        "required": [
+                            "item",
+                            "user",
+                        ],
+                        "title": "Body_update_item_items__item_id__put",
+                        "type": "object",
+                    },
+                    "HTTPValidationError": {
+                        "properties": {
+                            "detail": {
+                                "items": {
+                                    "$ref": "#/components/schemas/ValidationError",
+                                },
+                                "title": "Detail",
+                                "type": "array",
+                            },
+                        },
+                        "title": "HTTPValidationError",
+                        "type": "object",
+                    },
+                    "Item": {
+                        "properties": {
+                            "name": {
+                                "title": "Name",
+                                "type": "string",
+                            },
+                            "description": {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "price": {"title": "Price", "type": "number"},
+                            "tax": {
+                                "title": "Tax",
+                                "anyOf": [{"type": "number"}, {"type": "null"}],
+                            },
+                        },
+                        "required": [
+                            "name",
+                            "price",
+                        ],
+                        "title": "Item",
+                        "type": "object",
+                    },
+                    "User": {
+                        "properties": {
+                            "username": {
+                                "title": "Username",
+                                "type": "string",
+                            },
+                            "full_name": {
+                                "title": "Full Name",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                        },
+                        "required": [
+                            "username",
+                        ],
+                        "title": "User",
+                        "type": "object",
+                    },
+                    "ValidationError": {
+                        "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
+                            "loc": {
+                                "items": {
+                                    "anyOf": [
+                                        {
+                                            "type": "string",
+                                        },
+                                        {
+                                            "type": "integer",
+                                        },
+                                    ],
+                                },
+                                "title": "Location",
+                                "type": "array",
+                            },
+                            "msg": {
+                                "title": "Message",
+                                "type": "string",
+                            },
+                            "type": {
+                                "title": "Error Type",
+                                "type": "string",
+                            },
+                        },
+                        "required": [
+                            "loc",
+                            "msg",
+                            "type",
+                        ],
+                        "title": "ValidationError",
+                        "type": "object",
                     },
-                    "required": [
-                        "loc",
-                        "msg",
-                        "type",
-                    ],
-                    "title": "ValidationError",
-                    "type": "object",
                 },
             },
-        },
-    }
+        }
+    )
