@@ -2,6 +2,7 @@ import importlib
 
 import pytest
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 from ...utils import needs_py310
 
@@ -184,163 +185,167 @@ def test_put_missing_required_in_images(client: TestClient):
 def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {"title": "FastAPI", "version": "0.1.0"},
-        "paths": {
-            "/offers/": {
-                "post": {
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {"application/json": {"schema": {}}},
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {"title": "FastAPI", "version": "0.1.0"},
+            "paths": {
+                "/offers/": {
+                    "post": {
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {"application/json": {"schema": {}}},
+                            },
+                            "422": {
+                                "description": "Validation Error",
+                                "content": {
+                                    "application/json": {
+                                        "schema": {
+                                            "$ref": "#/components/schemas/HTTPValidationError"
+                                        }
+                                    }
+                                },
+                            },
                         },
-                        "422": {
-                            "description": "Validation Error",
+                        "summary": "Create Offer",
+                        "operationId": "create_offer_offers__post",
+                        "requestBody": {
                             "content": {
                                 "application/json": {
                                     "schema": {
-                                        "$ref": "#/components/schemas/HTTPValidationError"
+                                        "$ref": "#/components/schemas/Offer",
                                     }
                                 }
                             },
+                            "required": True,
                         },
-                    },
-                    "summary": "Create Offer",
-                    "operationId": "create_offer_offers__post",
-                    "requestBody": {
-                        "content": {
-                            "application/json": {
-                                "schema": {
-                                    "$ref": "#/components/schemas/Offer",
-                                }
-                            }
-                        },
-                        "required": True,
-                    },
+                    }
                 }
-            }
-        },
-        "components": {
-            "schemas": {
-                "Image": {
-                    "properties": {
-                        "url": {
-                            "title": "Url",
-                            "type": "string",
-                            "format": "uri",
-                            "maxLength": 2083,
-                            "minLength": 1,
-                        },
-                        "name": {
-                            "title": "Name",
-                            "type": "string",
-                        },
-                    },
-                    "required": ["url", "name"],
-                    "title": "Image",
-                    "type": "object",
-                },
-                "Item": {
-                    "properties": {
-                        "name": {
-                            "title": "Name",
-                            "type": "string",
-                        },
-                        "description": {
-                            "title": "Description",
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                        },
-                        "price": {
-                            "title": "Price",
-                            "type": "number",
-                        },
-                        "tax": {
-                            "title": "Tax",
-                            "anyOf": [{"type": "number"}, {"type": "null"}],
-                        },
-                        "tags": {
-                            "title": "Tags",
-                            "default": [],
-                            "type": "array",
-                            "items": {"type": "string"},
-                            "uniqueItems": True,
-                        },
-                        "images": {
-                            "anyOf": [
-                                {
-                                    "items": {
-                                        "$ref": "#/components/schemas/Image",
-                                    },
-                                    "type": "array",
-                                },
-                                {
-                                    "type": "null",
-                                },
-                            ],
-                            "title": "Images",
-                        },
-                    },
-                    "required": [
-                        "name",
-                        "price",
-                    ],
-                    "title": "Item",
-                    "type": "object",
-                },
-                "Offer": {
-                    "properties": {
-                        "name": {
-                            "title": "Name",
-                            "type": "string",
-                        },
-                        "description": {
-                            "title": "Description",
-                            "anyOf": [{"type": "string"}, {"type": "null"}],
-                        },
-                        "price": {
-                            "title": "Price",
-                            "type": "number",
-                        },
-                        "items": {
-                            "title": "Items",
-                            "type": "array",
-                            "items": {"$ref": "#/components/schemas/Item"},
-                        },
-                    },
-                    "required": ["name", "price", "items"],
-                    "title": "Offer",
-                    "type": "object",
-                },
-                "ValidationError": {
-                    "title": "ValidationError",
-                    "required": ["loc", "msg", "type"],
-                    "type": "object",
-                    "properties": {
-                        "loc": {
-                            "title": "Location",
-                            "type": "array",
-                            "items": {
-                                "anyOf": [{"type": "string"}, {"type": "integer"}]
+            },
+            "components": {
+                "schemas": {
+                    "Image": {
+                        "properties": {
+                            "url": {
+                                "title": "Url",
+                                "type": "string",
+                                "format": "uri",
+                                "maxLength": 2083,
+                                "minLength": 1,
+                            },
+                            "name": {
+                                "title": "Name",
+                                "type": "string",
                             },
                         },
-                        "msg": {"title": "Message", "type": "string"},
-                        "type": {"title": "Error Type", "type": "string"},
-                        "input": {"title": "Input"},
-                        "ctx": {"title": "Context", "type": "object"},
+                        "required": ["url", "name"],
+                        "title": "Image",
+                        "type": "object",
                     },
-                },
-                "HTTPValidationError": {
-                    "title": "HTTPValidationError",
-                    "type": "object",
-                    "properties": {
-                        "detail": {
-                            "title": "Detail",
-                            "type": "array",
-                            "items": {"$ref": "#/components/schemas/ValidationError"},
-                        }
+                    "Item": {
+                        "properties": {
+                            "name": {
+                                "title": "Name",
+                                "type": "string",
+                            },
+                            "description": {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "price": {
+                                "title": "Price",
+                                "type": "number",
+                            },
+                            "tax": {
+                                "title": "Tax",
+                                "anyOf": [{"type": "number"}, {"type": "null"}],
+                            },
+                            "tags": {
+                                "title": "Tags",
+                                "default": [],
+                                "type": "array",
+                                "items": {"type": "string"},
+                                "uniqueItems": True,
+                            },
+                            "images": {
+                                "anyOf": [
+                                    {
+                                        "items": {
+                                            "$ref": "#/components/schemas/Image",
+                                        },
+                                        "type": "array",
+                                    },
+                                    {
+                                        "type": "null",
+                                    },
+                                ],
+                                "title": "Images",
+                            },
+                        },
+                        "required": [
+                            "name",
+                            "price",
+                        ],
+                        "title": "Item",
+                        "type": "object",
                     },
-                },
-            }
-        },
-    }
+                    "Offer": {
+                        "properties": {
+                            "name": {
+                                "title": "Name",
+                                "type": "string",
+                            },
+                            "description": {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "price": {
+                                "title": "Price",
+                                "type": "number",
+                            },
+                            "items": {
+                                "title": "Items",
+                                "type": "array",
+                                "items": {"$ref": "#/components/schemas/Item"},
+                            },
+                        },
+                        "required": ["name", "price", "items"],
+                        "title": "Offer",
+                        "type": "object",
+                    },
+                    "ValidationError": {
+                        "title": "ValidationError",
+                        "required": ["loc", "msg", "type"],
+                        "type": "object",
+                        "properties": {
+                            "loc": {
+                                "title": "Location",
+                                "type": "array",
+                                "items": {
+                                    "anyOf": [{"type": "string"}, {"type": "integer"}]
+                                },
+                            },
+                            "msg": {"title": "Message", "type": "string"},
+                            "type": {"title": "Error Type", "type": "string"},
+                            "input": {"title": "Input"},
+                            "ctx": {"title": "Context", "type": "object"},
+                        },
+                    },
+                    "HTTPValidationError": {
+                        "title": "HTTPValidationError",
+                        "type": "object",
+                        "properties": {
+                            "detail": {
+                                "title": "Detail",
+                                "type": "array",
+                                "items": {
+                                    "$ref": "#/components/schemas/ValidationError"
+                                },
+                            }
+                        },
+                    },
+                }
+            },
+        }
+    )
