@@ -1,7 +1,6 @@
 import importlib
 
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 from inline_snapshot import snapshot
 
@@ -64,22 +63,12 @@ def test_header_param_model_invalid(client: TestClient):
     assert response.json() == snapshot(
         {
             "detail": [
-                IsDict(
-                    {
-                        "type": "missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "Field required",
-                        "input": {"x_tag": [], "host": "testserver"},
-                    }
-                )
-                | IsDict(
-                    # TODO: remove when deprecating Pydantic v1
-                    {
-                        "type": "value_error.missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "field required",
-                    }
-                )
+                {
+                    "type": "missing",
+                    "loc": ["header", "save_data"],
+                    "msg": "Field required",
+                    "input": {"x_tag": [], "host": "testserver"},
+                }
             ]
         }
     )
@@ -93,22 +82,12 @@ def test_header_param_model_extra(client: TestClient):
     assert response.json() == snapshot(
         {
             "detail": [
-                IsDict(
-                    {
-                        "type": "extra_forbidden",
-                        "loc": ["header", "tool"],
-                        "msg": "Extra inputs are not permitted",
-                        "input": "plumbus",
-                    }
-                )
-                | IsDict(
-                    # TODO: remove when deprecating Pydantic v1
-                    {
-                        "type": "value_error.extra",
-                        "loc": ["header", "tool"],
-                        "msg": "extra fields not permitted",
-                    }
-                )
+                {
+                    "type": "extra_forbidden",
+                    "loc": ["header", "tool"],
+                    "msg": "Extra inputs are not permitted",
+                    "input": "plumbus",
+                }
             ]
         }
     )
@@ -143,37 +122,19 @@ def test_openapi_schema(client: TestClient):
                                 "name": "if-modified-since",
                                 "in": "header",
                                 "required": False,
-                                "schema": IsDict(
-                                    {
-                                        "anyOf": [{"type": "string"}, {"type": "null"}],
-                                        "title": "If Modified Since",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "type": "string",
-                                        "title": "If Modified Since",
-                                    }
-                                ),
+                                "schema": {
+                                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                                    "title": "If Modified Since",
+                                },
                             },
                             {
                                 "name": "traceparent",
                                 "in": "header",
                                 "required": False,
-                                "schema": IsDict(
-                                    {
-                                        "anyOf": [{"type": "string"}, {"type": "null"}],
-                                        "title": "Traceparent",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "type": "string",
-                                        "title": "Traceparent",
-                                    }
-                                ),
+                                "schema": {
+                                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                                    "title": "Traceparent",
+                                },
                             },
                             {
                                 "name": "x-tag",
@@ -223,6 +184,8 @@ def test_openapi_schema(client: TestClient):
                     },
                     "ValidationError": {
                         "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
                             "loc": {
                                 "items": {
                                     "anyOf": [{"type": "string"}, {"type": "integer"}]
