@@ -1,15 +1,20 @@
 import importlib
+from pathlib import Path
 
 import pytest
 from fastapi.testclient import TestClient
 from inline_snapshot import snapshot
 
+from ...utils import needs_py310
+
 
 @pytest.fixture(
     name="client",
     params=[
-        "tutorial001_03_py39",
-        "tutorial001_03_an_py39",
+        pytest.param("tutorial001_02_py39"),
+        pytest.param("tutorial001_02_py310", marks=needs_py310),
+        pytest.param("tutorial001_02_an_py39"),
+        pytest.param("tutorial001_02_an_py310", marks=needs_py310),
     ],
 )
 def get_client(request: pytest.FixtureRequest):
@@ -19,7 +24,19 @@ def get_client(request: pytest.FixtureRequest):
     return client
 
 
-def test_post_file(tmp_path, client: TestClient):
+def test_post_form_no_body(client: TestClient):
+    response = client.post("/files/")
+    assert response.status_code == 200, response.text
+    assert response.json() == {"message": "No file sent"}
+
+
+def test_post_uploadfile_no_body(client: TestClient):
+    response = client.post("/uploadfile/")
+    assert response.status_code == 200, response.text
+    assert response.json() == {"message": "No upload file sent"}
+
+
+def test_post_file(tmp_path: Path, client: TestClient):
     path = tmp_path / "test.txt"
     path.write_bytes(b"<file content>")
 
@@ -29,7 +46,7 @@ def test_post_file(tmp_path, client: TestClient):
     assert response.json() == {"file_size": 14}
 
 
-def test_post_upload_file(tmp_path, client: TestClient):
+def test_post_upload_file(tmp_path: Path, client: TestClient):
     path = tmp_path / "test.txt"
     path.write_bytes(b"<file content>")
 
@@ -58,8 +75,7 @@ def test_openapi_schema(client: TestClient):
                                         "$ref": "#/components/schemas/Body_create_file_files__post"
                                     }
                                 }
-                            },
-                            "required": True,
+                            }
                         },
                         "responses": {
                             "200": {
@@ -90,8 +106,7 @@ def test_openapi_schema(client: TestClient):
                                         "$ref": "#/components/schemas/Body_create_upload_file_uploadfile__post"
                                     }
                                 }
-                            },
-                            "required": True,
+                            }
                         },
                         "responses": {
                             "200": {
@@ -116,27 +131,27 @@ def test_openapi_schema(client: TestClient):
                 "schemas": {
                     "Body_create_file_files__post": {
                         "title": "Body_create_file_files__post",
-                        "required": ["file"],
                         "type": "object",
                         "properties": {
                             "file": {
                                 "title": "File",
-                                "type": "string",
-                                "description": "A file read as bytes",
-                                "format": "binary",
+                                "anyOf": [
+                                    {"type": "string", "format": "binary"},
+                                    {"type": "null"},
+                                ],
                             }
                         },
                     },
                     "Body_create_upload_file_uploadfile__post": {
                         "title": "Body_create_upload_file_uploadfile__post",
-                        "required": ["file"],
                         "type": "object",
                         "properties": {
                             "file": {
                                 "title": "File",
-                                "type": "string",
-                                "description": "A file read as UploadFile",
-                                "format": "binary",
+                                "anyOf": [
+                                    {"type": "string", "format": "binary"},
+                                    {"type": "null"},
+                                ],
                             }
                         },
                     },
@@ -158,6 +173,8 @@ def test_openapi_schema(client: TestClient):
                         "required": ["loc", "msg", "type"],
                         "type": "object",
                         "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
                             "loc": {
                                 "title": "Location",
                                 "type": "array",
@@ -167,8 +184,6 @@ def test_openapi_schema(client: TestClient):
                             },
                             "msg": {"title": "Message", "type": "string"},
                             "type": {"title": "Error Type", "type": "string"},
-                            "input": {"title": "Input"},
-                            "ctx": {"title": "Context", "type": "object"},
                         },
                     },
                 }
